@@ -30,10 +30,14 @@ __all__ = (
     "ProfilingGroupDescriptionTypeDef",
     "CreateProfilingGroupResponseTypeDef",
     "DescribeProfilingGroupResponseTypeDef",
+    "GetPolicyResponseTypeDef",
     "GetProfileResponseTypeDef",
     "ProfileTimeTypeDef",
     "ListProfileTimesResponseTypeDef",
     "ListProfilingGroupsResponseTypeDef",
+    "PaginatorConfigTypeDef",
+    "PutPermissionResponseTypeDef",
+    "RemovePermissionResponseTypeDef",
     "UpdateProfilingGroupResponseTypeDef",
 )
 
@@ -86,6 +90,8 @@ DescribeProfilingGroupResponseTypeDef = TypedDict(
     "DescribeProfilingGroupResponseTypeDef", {"profilingGroup": ProfilingGroupDescriptionTypeDef}
 )
 
+GetPolicyResponseTypeDef = TypedDict("GetPolicyResponseTypeDef", {"policy": str, "revisionId": str})
+
 _RequiredGetProfileResponseTypeDef = TypedDict(
     "_RequiredGetProfileResponseTypeDef", {"contentType": str, "profile": Union[bytes, IO]}
 )
@@ -132,6 +138,18 @@ class ListProfilingGroupsResponseTypeDef(
     pass
 
 
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
+)
+
+PutPermissionResponseTypeDef = TypedDict(
+    "PutPermissionResponseTypeDef", {"policy": str, "revisionId": str}
+)
+
+RemovePermissionResponseTypeDef = TypedDict(
+    "RemovePermissionResponseTypeDef", {"policy": str, "revisionId": str}
+)
+
 UpdateProfilingGroupResponseTypeDef = TypedDict(
     "UpdateProfilingGroupResponseTypeDef", {"profilingGroup": ProfilingGroupDescriptionTypeDef}
 )
